@@ -21,7 +21,7 @@ if ( !isGeneric("alignGeometry") ) {
 #' not given, too, all bands will be considered for resampling.
 #' @param method Method for resampling; "bilinear" for bilinear interpolation 
 #' (default) or "ngb" for nearest neighbor interpolation. See e.g. 
-#' \code{\link{resample}}, \code{\link{projectRaster}}.
+#' \code{\link[raster]{resample}}, \code{\link[raster]{projectRaster}}.
 #'  
 #' @export alignGeometry
 #' 
@@ -93,7 +93,7 @@ setMethod("alignGeometry",
             method <- method[1]
             if(raster::projection(x) == raster::projection(template)){
               x <- raster::crop(x, template, snap = "out")
-              if(class(template) == "RasterLayer"){
+              if (inherits(template, "RasterLayer")) {
                 if(x@ncols / template@ncols >= 2){
                   factor <- floor(x@ncols/template@ncols)
                   x <- raster::aggregate(x, fact = factor, fun = mean, 
