@@ -10,7 +10,7 @@ if ( !isGeneric("calcAtmosCorr") ) {
 #' \itemize{
 #'   \item absolute radiance correction
 #'   \item DOS2: a dark object substraction model by Chavez (1996)
-#'   \item DOS4: a dark object substratcion model by Moran et al. (1992)
+#'   \item DOS4: a dark object substraction model by Moran et al. (1992)
 #' }
 #'
 #' @param x Satellite or Raster* object providing the radiance at the sensor.
@@ -25,7 +25,10 @@ if ( !isGeneric("calcAtmosCorr") ) {
 #' from \code{\link{calcTOAIrradRadRef}}, \code{\link{calcTOAIrradTable}} 
 #' or \code{\link{calcTOAIrradModel}}.
 #' @param szen Sun zenith angle.
-#'
+#' 
+#' @return Depending on 'x', a Satellite or Raster* object with added 
+#'   atmospheric corrected layers.
+#' 
 #' @export calcAtmosCorr
 #' 
 #' @name calcAtmosCorr
@@ -67,29 +70,26 @@ if ( !isGeneric("calcAtmosCorr") ) {
 #'    
 #' @references Chavez Jr PS (1988) An improved dark-object subtraction technique 
 #' for atmospheric scattering correction of multispectral data. Remote Sensing 
-#' of Environment 24/3, doi:10.1016/0034-4257(88)90019-3, available online at
-#'  \url{http://www.sciencedirect.com/science/article/pii/0034425788900193}
+#' of Environment 24/3, \doi{10.1016/0034-4257(88)90019-3}.
 #'  
 #' Chavez Jr PS (1996) Image-based atmospheric corrections revisited and
 #' improved. Photogrammetric Engineering and Remote Sensing 62/9,
 #' available online at 
-#' \url{http://info.asprs.org/publications/pers/96journal/september/1996_sep_1025-1036.pdf}
+#' \url{https://www.researchgate.net/publication/236769129_Image-Based_Atmospheric_Corrections_-_Revisited_and_Improved}
 #'  
 #' Goslee SC (2011) Analyzing Remote Sensing Data in R: The landsat 
-#' Package. Journal of Statistical Software,43/4, 1-25. URL 
-#' \url{http://www.jstatsoft.org/v43/i04/}.
+#' Package. Journal of Statistical Software,43/4, 1-25, 
+#' \doi{10.18637/jss.v043.i04}.
 #' 
 #' Moran MS, Jackson RD, Slater PN, Teillet PM (1992) Evaluation of simplified
 #' procedures for retrieval of land surface reflectance factors from satellite
 #' sensor output.Remote Sensing of Environment 41/2-3, 169-184, 
-#' doi:10.1016/0034-4257(92)90076-V, 
-#' URL \url{http://www.sciencedirect.com/science/article/pii/003442579290076V}.
+#' \doi{10.1016/0034-4257(92)90076-V}.
 #' 
 #' Song C, Woodcock CE, Seto KC, Lenney MP, Macomber SA (2001) Classification 
 #' and Change Detection Using Landsat TM Data: When and How to Correct 
 #' Atmospheric Effects? Remote Sensing of Environment 75/2, 
-#' doi:10.1016/S0034-4257(00)00169-3, URL
-#' \url{http://www.sciencedirect.com/science/article/pii/S0034425700001693}
+#' \doi{10.1016/S0034-4257(00)00169-3}.
 #' 
 #'
 #' @examples
@@ -131,7 +131,6 @@ NULL
 
 
 # Function using satellite object ----------------------------------------------
-#' @return Satellite object with added atmospheric corrected layers
 #' @rdname calcAtmosCorr
 setMethod("calcAtmosCorr", 
           signature(x = "Satellite"), 
@@ -161,7 +160,8 @@ setMethod("calcAtmosCorr",
                                   path_rad = getSatPRAD(x, bcde_rad),
                                   esun = getSatESUN(x, bcde_rad),
                                   szen = getSatSZEN(x, bcde_rad), 
-                                  model = "DOS2")
+                                  model = model)
+              
               layer_bcde <- paste0(substr(bcde_rad, 1, nchar(bcde_rad) - 4),
                                    "_REF_AtmosCorr")
               meta_param <- data.frame(getSatSensorInfo(x),
@@ -180,7 +180,6 @@ setMethod("calcAtmosCorr",
 
 
 # Function using raster::RasterStack object ------------------------------------
-#' @return raster::RasterStack object with atmospheric corrected layers
 #' @rdname calcAtmosCorr
 setMethod("calcAtmosCorr", 
           signature(x = "RasterStack"), 
@@ -196,7 +195,6 @@ setMethod("calcAtmosCorr",
 
 
 # Function using raster::RasterLayer object ------------------------------------
-#' @return raster::RasterLayer object with atmospheric corrected layer
 #' @rdname calcAtmosCorr
 setMethod("calcAtmosCorr", 
           signature(x = "RasterLayer"), 
